@@ -6,9 +6,7 @@ namespace Doctrine\Common\DataFixtures\Event\Listener;
 
 use Doctrine\Common\DataFixtures\ReferenceRepository;
 use Doctrine\Common\EventSubscriber;
-use Doctrine\ORM\Event\LifecycleEventArgs;
-
-use function get_class;
+use Doctrine\ORM\Event\PostPersistEventArgs;
 
 /**
  * Reference Listener populates identities for
@@ -16,18 +14,14 @@ use function get_class;
  */
 final class ORMReferenceListener implements EventSubscriber
 {
-    /** @var ReferenceRepository */
-    private $referenceRepository;
-
-    public function __construct(ReferenceRepository $referenceRepository)
+    public function __construct(private ReferenceRepository $referenceRepository)
     {
-        $this->referenceRepository = $referenceRepository;
     }
 
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    public function getSubscribedEvents()
+    public function getSubscribedEvents(): array
     {
         // would be better to use onClear, but it is supported only in 2.1
         return ['postPersist'];
@@ -35,10 +29,8 @@ final class ORMReferenceListener implements EventSubscriber
 
     /**
      * Populates identities for stored references
-     *
-     * @return void
      */
-    public function postPersist(LifecycleEventArgs $args)
+    public function postPersist(PostPersistEventArgs $args): void
     {
         $object = $args->getObject();
 
@@ -52,7 +44,7 @@ final class ORMReferenceListener implements EventSubscriber
                 ->getUnitOfWork()
                 ->getEntityIdentifier($object);
 
-            $this->referenceRepository->setReferenceIdentity($name, $identity, get_class($object));
+            $this->referenceRepository->setReferenceIdentity($name, $identity, $object::class);
         }
     }
 }
