@@ -11,7 +11,7 @@ final class MultipleTransactionORMExecutor extends AbstractExecutor
     use ORMExecutorCommon;
 
     /** @inheritDoc */
-    public function execute(array $fixtures, $append = false): void
+    public function execute(array $fixtures, bool $append = false): void
     {
         $executor = $this;
         if ($append === false) {
