@@ -6,19 +6,17 @@ namespace Doctrine\Tests\Common\DataFixtures\TestDocument;
 
 use Doctrine\ODM\MongoDB\Mapping\Annotations as ODM;
 
-/** @ODM\Document */
+#[ODM\Document]
 class Role
 {
-    /** @ODM\Id */
-    private ?string $id = null;
+    #[ODM\Id]
+    private string|null $id = null;
 
-    /**
-     * @ODM\Field(type="string")
-     * @ODM\Index
-     */
-    private ?string $name = null;
+    #[ODM\Field(type: 'string')]
+    #[ODM\Index]
+    private string|null $name = null;
 
-    public function getId(): ?string
+    public function getId(): string|null
     {
         return $this->id;
     }
@@ -28,7 +26,7 @@ class Role
         $this->name = $name;
     }
 
-    public function getName(): ?string
+    public function getName(): string|null
     {
         return $this->name;
     }
