@@ -6,32 +6,23 @@ namespace Doctrine\Tests\Common\DataFixtures\TestEntity;
 
 use Doctrine\ORM\Mapping as ORM;
 
-/** @ORM\Entity() */
 #[ORM\Entity]
 class Group
 {
-    /**
-     * @ORM\Column(type="integer")
-     * @ORM\Id
-     */
     #[ORM\Column]
     #[ORM\Id]
-    private ?int $id = null;
+    private int|null $id = null;
 
-    /**
-     * @ORM\Column(length=32)
-     * @ORM\Id
-     */
     #[ORM\Column(length: 32)]
     #[ORM\Id]
-    private ?string $code = null;
+    private string|null $code = null;
 
     public function setId(int $id): void
     {
         $this->id = $id;
     }
 
-    public function getId(): ?int
+    public function getId(): int|null
     {
         return $this->id;
     }
@@ -41,7 +32,7 @@ class Group
         $this->code = $code;
     }
 
-    public function getCode(): ?string
+    public function getCode(): string|null
     {
         return $this->code;
     }
