@@ -7,21 +7,15 @@ namespace Doctrine\Tests\Common\DataFixtures\TestEntity;
 use Doctrine\ORM\Mapping as ORM;
 use Doctrine\Tests\Common\DataFixtures\TestValueObjects\Uuid;
 
-/** @ORM\Entity */
 #[ORM\Entity]
 class Link
 {
-    /**
-     * @ORM\Id
-     * @ORM\Column(type="uuid")
-     */
     #[ORM\Id]
     #[ORM\Column(type: 'uuid')]
     private Uuid $id;
 
-    /** @ORM\Column(length=150) */
     #[ORM\Column(length: 150)]
-    private ?string $url = null;
+    private string|null $url = null;
 
     public function __construct(Uuid $id)
     {
@@ -33,7 +27,7 @@ class Link
         return $this->id;
     }
 
-    public function getUrl(): ?string
+    public function getUrl(): string|null
     {
         return $this->url;
     }
